@@ -1,10 +1,14 @@
+from __future__ import unicode_literals
 
 '''Add some missing HttpResponse sub-classes'''
 from django.core.exceptions import SuspiciousOperation
 from django.http import HttpResponse, Http404
 from django.utils.encoding import iri_to_uri
 
-from urlparse import urlparse
+try:
+  from urlparse import urlparse
+except ImportError:
+  from urllib.parse import urlparse
 try:
     from collections import OrderedDict
 except ImportError:
@@ -169,7 +173,7 @@ class NotFound(HttpResponseError):
 
 class MethodNotAllowed(HttpResponseError):
     def __init__(self, permitted_methods, *args, **kwargs):
-        super(HttpResponseNotAllowed, self).__init__(*args, **kwargs)
+        super(MethodNotAllowed, self).__init__(*args, **kwargs)
         self['Allow'] = ', '.join(permitted_methods)
 
     status_code = STATUS.METHOD_NOT_ALLOWED
